<?php
/**
 * @since      1.1.17
 * @package    Wallkit_Wp
 * @subpackage Wallkit_Wp/includes
 * @author     Wallkit <dev@wallkit.net>
 */
class Wallkit_Wp_Access {


    /**
     * @var null
     */
    private static $instance = null;

    /**
     * @var null|Wallkit_Wp_Collection
     */
    private static $wallkit_Wp_Collection = null;

	/**
	 * Content Key prefix
	 */
	private $content_key_prefix='';

    /**
     * Wallkit_Wp_Access constructor.
     *
     * @param Wallkit_Wp_Collection $wallkit_Wp_Collection
     */
    private function __construct(Wallkit_Wp_Collection $wallkit_Wp_Collection) {
	    $this->setContentKeyPrefix();
        static::$wallkit_Wp_Collection = $wallkit_Wp_Collection;
    }

	/**
	 * Set Content Key Prefix
	 */
	private function setContentKeyPrefix() {
		if (is_multisite()) {
			global $wpdb;
			$this->content_key_prefix = $wpdb->prefix;
		}
	}

    /**
     * @param Wallkit_Wp_Collection $wallkit_Wp_Collection
     * @return null|Wallkit_Wp_Access
     */
    public static function getInstance(Wallkit_Wp_Collection $wallkit_Wp_Collection)
    {
        if (null === self::$instance)
        {
            self::$instance = new self($wallkit_Wp_Collection);
        }
        return self::$instance;
    }
    
    /**
     * @return \Wallkit_Wp_Admin_Posts
     */
    public function get_wk_posts() {
        return  new Wallkit_Wp_Admin_Posts(static::$wallkit_Wp_Collection);
    }

    /**
     *
     */
    private function __clone () {}

    /**
     *
     */
    private function __wakeup () {}
    
    /**
     * @param \WP_Post|null $WP_Post
     * @param bool $autoCreate
     * @return bool
     */
    public function check_post_access(WP_Post $WP_Post = null) {

        if(!$WP_Post instanceof WP_Post || !isset($WP_Post->ID))
        {
            return true;
        }

        if(!isset($WP_Post->post_type) || empty($WP_Post->post_type))
        {
            return true;
        }

        try {

            /**
             * Disable locked content if user logged in admin area
             */
            if(is_user_logged_in() && !self::$wallkit_Wp_Collection->get_settings()->get_option("wk_admin_paywall"))
            {
                return true;
            }

            if(!self::$wallkit_Wp_Collection->get_settings()->get_option("wk_check_post_access"))
            {
                return true;
            }

            /**
             * Locked content for checked post types
             */
            $registeredPostTypes = self::$wallkit_Wp_Collection->get_settings()->get_option("wk_check_post_type_access");

            return !(!empty($registeredPostTypes) && array_key_exists($WP_Post->post_type, $registeredPostTypes) && $registeredPostTypes[$WP_Post->post_type]);

        }
        catch (\Exception $exception)
        {
            return false;
        }

    }

}
